@@ -1,4 +1,4 @@
-# $Id: State.pm,v 1.1 2005/04/14 19:23:17 chris Exp $
+# $Id: State.pm,v 1.4 2005/04/28 14:18:20 chris Exp $
 #
 # POE::Component::IRC::Qnet::State, by Chris Williams
 #
@@ -40,34 +40,35 @@ use constant CMD_SUB => 1; # Command handler.
 
 $VERSION = '1.3';
 
+my ($GOT_CLIENT_DNS);
+my ($GOT_SSL);
+
+BEGIN {
+    $GOT_CLIENT_DNS = 0;
+    eval {
+      require POE::Component::Client::DNS;
+      $GOT_CLIENT_DNS = 1;
+    };
+}
+
+BEGIN {
+    $GOT_SSL = 0;
+    eval {
+      require POE::Component::SSLify;
+      import POE::Component::SSLify qw( Client_SSLify );
+      $GOT_SSL = 1;
+    };
+}
+
 sub _create {
   my ($package) = shift;
 
   my $self = bless ( { }, $package );
 
-  BEGIN {
-    my $has_client_dns = 0;
-    eval {
-      require POE::Component::Client::DNS;
-      $has_client_dns = 1;
-    };
-    $self->{HAS_CLIENT_DNS} = $has_client_dns;
-  }
-
-  if ( $self->{HAS_CLIENT_DNS} ) {
+  if ( $GOT_CLIENT_DNS ) {
     POE::Component::Client::DNS->spawn( Alias => "irc_resolver" );
   }
 
-  BEGIN {
-    my $has_ssl = 0;
-    eval {
-      require POE::Component::SSLify;
-      import POE::Component::SSLify qw( Client_SSLify );
-      $has_ssl = 1;
-    };
-    $self->{HAS_SSL} = $has_ssl;
-  }
-
   $self->{IRC_CMDS} =
   { 'rehash'    => [ PRI_HIGH,   'noargs',        ],
     'restart'   => [ PRI_HIGH,   'noargs',        ],
@@ -108,6 +109,8 @@ sub _create {
     'whois'     => [ PRI_HIGH,   'commasep',      ],
     'ctcp'      => [ PRI_HIGH,   'ctcp',          ],
     'ctcpreply' => [ PRI_HIGH,   'ctcp',          ],
+    'ping'      => [ PRI_HIGH,   'oneortwo',      ],
+    'pong'      => [ PRI_HIGH,   'oneortwo',      ],
   };
 
   $self->{IRC_EVTS} = [ qw(001 ping join part kick nick mode quit 354 324 315 disconnected socketerr error) ];
@@ -226,6 +229,8 @@ sub _parseline {
   my ($session, $self, $line) = @_[SESSION, OBJECT, ARG0];
   my (@events, @cooked);
 
+  $self->_send_event( 'irc_raw' => $line ) if ( $self->{raw_events} );
+
   # Feed the proper Filter object the raw IRC text and get the
   # "cooked" events back for sending, then deliver each event. We
   # handle CTCPs separately from normal IRC messages here, to avoid
@@ -246,7 +251,7 @@ sub _parseline {
         $self->{RealNick} = ( split / /, $line )[2];
     }
     if ( $ev->{name} eq 'nick' or $ev->{name} eq 'quit' ) {
-        push ( @{$ev->{args}}, [ $self->nick_channels( ( split /!/, $ev->{args}->[0] )[0] ) ] );
+        push ( @{$ev->{args}}, [ $self->nick_channels( ( split( /!/, $ev->{args}->[0] ) )[0] ) ] );
     }
     $ev->{name} = 'irc_' . $ev->{name};
     $self->_send_event( $ev->{name}, @{$ev->{args}} );
